@@ -1,28 +1,11 @@
-################################################################################
-#  Copyright (C) 2002-2015  Travis Shirk <travis@pobox.com>
-#
-#  This program is free software; you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation; either version 2 of the License, or
-#  (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, see <http://www.gnu.org/licenses/>.
-#
-################################################################################
+import deprecation
 from math import log10
 
 from . import Mp3Exception
-
 from ..utils.binfuncs import bytes2bin, bytes2dec, bin2dec
-from .. import compat
-
 from ..utils.log import getLogger
+from ..__about__ import __version__
+
 log = getLogger(__name__)
 
 
@@ -36,7 +19,7 @@ def isValidHeader(header):
         # mpeg v2.5 (bits 20,19)
         return False
 
-    # All the remaining tests are not entireley required, but do help in
+    # All the remaining tests are not entirely required, but do help in
     # finding false syncs
 
     version = (header >> 19) & 0x3
@@ -74,43 +57,48 @@ def findHeader(fp, start_pos=0):
     """
 
     def isBOM(buffer, pos):
+        """Check for unicode BOM"""
         try:
-            return 254 in (buffer[pos + 1], buffer[pos - 1])
+            if pos - 1 >= 0:
+                if buffer[pos - 1] == 254:
+                    return True
+            return buffer[pos + 1] == 254
         except IndexError:
             return False
 
-    def find_sync(fp, start_pos=0):
-        CHUNK_SIZE = 8192  # Measured as optimal
+    def find_sync(_fp, _pos=0):
+        chunk_sz = 8192  # Measured as optimal
 
-        fp.seek(start_pos)
-        data = fp.read(CHUNK_SIZE)
+        _fp.seek(_pos)
+        data = _fp.read(chunk_sz)
 
         while data:
             pos = 0
-            while pos >= 0 and pos < CHUNK_SIZE:
+            while 0 <= pos < chunk_sz:
                 pos = data.find(b"\xff", pos)
                 if pos == -1:
                     break
 
                 if not isBOM(data, pos):
-                    header = data[pos:pos + 4]
-                    if len(header) == 4:
-                        return (start_pos + pos, header)
+                    h = data[pos:pos + 4]
+                    if len(h) == 4:
+                        return tuple([_pos + pos, h])
 
                 pos += 1
 
-            start_pos += len(data)
-            data = fp.read(CHUNK_SIZE)
+            _pos += len(data)
+            data = _fp.read(chunk_sz)
 
-        return (None, None)
+        return None, None
 
     sync_pos, header_bytes = find_sync(fp, start_pos)
     while sync_pos is not None:
         header = bytes2dec(header_bytes)
         if isValidHeader(header):
-            return (sync_pos, header, header_bytes)
+            return tuple([sync_pos, header, header_bytes])
         sync_pos, header_bytes = find_sync(fp, start_pos + sync_pos + 2)
-    return (None, None, None)
+
+    return None, None, None
 
 
 def timePerFrame(mp3_header, vbr):
@@ -128,11 +116,11 @@ def timePerFrame(mp3_header, vbr):
             float(mp3_header.sample_freq))
 
 
+@deprecation.deprecated(deprecated_in="0.9a2", removed_in="1.0", current_version=__version__,
+                        details="Use timePerFrame instead")
 def compute_time_per_frame(mp3_header):
-    """Deprecated, use timePerFrame instead."""
-    import warnings
-    warnings.warn("Use timePerFrame instead", DeprecationWarning, stacklevel=2)
-    return timePerFrame(mp3_header, False)
+    if mp3_header is not None:
+        return timePerFrame(mp3_header, False)
 
 
 class Mp3Header:
@@ -326,9 +314,9 @@ class XingHeader:
     # frame, and false otherwise.
     def decode(self, frame):
         # mp3 version
-        version = (compat.byteOrd(frame[1]) >> 3) & 0x1
+        version = (frame[1] >> 3) & 0x1
         # channel mode.
-        mode = (compat.byteOrd(frame[3]) >> 6) & 0x3
+        mode = (frame[3] >> 6) & 0x3
 
         # Find the start of the Xing header.
         if version:
@@ -383,73 +371,73 @@ class XingHeader:
         return True
 
 
-##
-# \brief Mp3 Info tag (AKA LAME Tag)
-#
-#  Lame (and some other encoders) write a tag containing various bits of info
-#  about the options used at encode time.  If available, the following are
-#  parsed and stored in the LameHeader dict:
-#
-#  encoder_version: short encoder version [str]
-#  tag_revision:    revision number of the tag [int]
-#  vbr_method:      VBR method used for encoding [str]
-#  lowpass_filter:  lowpass filter frequency in Hz [int]
-#  replaygain:      if available, radio and audiofile gain (see below) [dict]
-#  encoding_flags:  encoding flags used [list]
-#  nogap:           location of gaps when --nogap was used [list]
-#  ath_type:        ATH type [int]
-#  bitrate:         bitrate and type (Constant, Target, Minimum) [tuple]
-#  encoder_delay:   samples added at the start of the mp3 [int]
-#  encoder_padding: samples added at the end of the mp3 [int]
-#  noise_shaping:   noise shaping method [int]
-#  stereo_mode:     stereo mode used [str]
-#  unwise_settings: whether unwise settings were used [boolean]
-#  sample_freq:     source sample frequency [str]
-#  mp3_gain:        mp3 gain adjustment (rarely used) [float]
-#  preset:          preset used [str]
-#  surround_info:   surround information [str]
-#  music_length:    length in bytes of original mp3 [int]
-#  music_crc:       CRC-16 of the mp3 music data [int]
-#  infotag_crc:     CRC-16 of the info tag [int]
-#
-#  Prior to ~3.90, Lame simply stored the encoder version in the first frame.
-#  If the infotag_crc is invalid, then we try to read this version string.  A
-#  simple way to tell if the LAME Tag is complete is to check for the
-#  infotag_crc key.
-#
-#  Replay Gain data is only available since Lame version 3.94b.  If set, the
-#  replaygain dict has the following structure:
-#
-# \code
-#     peak_amplitude: peak signal amplitude [float]
-#     radio:
-#        name:       name of the gain adjustment [str]
-#        adjustment: gain adjustment [float]
-#        originator: originator of the gain adjustment [str]
-#     audiofile: [same as radio]
-# \endcode
-#
-#  Note that as of 3.95.1, Lame uses 89dB as a reference level instead of the
-#  83dB that is specified in the Replay Gain spec.  This is not automatically
-#  compensated for.  You can do something like this if you want:
-#
-# \code
-#     import eyeD3
-#     af = eyeD3.mp3.Mp3AudioFile('/path/to/some.mp3')
-#     lamever = af.lameTag['encoder_version']
-#     name, ver = lamever[:4], lamever[4:]
-#     gain = af.lameTag['replaygain']['radio']['adjustment']
-#     if name == 'LAME' and eyeD3.mp3.lamevercmp(ver, '3.95') > 0:
-#         gain -= 6
-# \endcode
-#
-#  Radio and Audiofile Replay Gain are often referrered to as Track and Album
-#  gain, respectively.  See http://replaygain.hydrogenaudio.org/ for futher
-#  details on Replay Gain.
-#
-#  See http://gabriel.mp3-tech.org/mp3infotag.html for the gory details of the
-#  LAME Tag.
 class LameHeader(dict):
+    r""" Mp3 Info tag (AKA LAME Tag)
+
+    Lame (and some other encoders) write a tag containing various bits of info
+    about the options used at encode time.  If available, the following are
+    parsed and stored in the LameHeader dict:
+
+    encoder_version: short encoder version [str]
+    tag_revision:    revision number of the tag [int]
+    vbr_method:      VBR method used for encoding [str]
+    lowpass_filter:  lowpass filter frequency in Hz [int]
+    replaygain:      if available, radio and audiofile gain (see below) [dict]
+    encoding_flags:  encoding flags used [list]
+    nogap:           location of gaps when --nogap was used [list]
+    ath_type:        ATH type [int]
+    bitrate:         bitrate and type (Constant, Target, Minimum) [tuple]
+    encoder_delay:   samples added at the start of the mp3 [int]
+    encoder_padding: samples added at the end of the mp3 [int]
+    noise_shaping:   noise shaping method [int]
+    stereo_mode:     stereo mode used [str]
+    unwise_settings: whether unwise settings were used [boolean]
+    sample_freq:     source sample frequency [str]
+    mp3_gain:        mp3 gain adjustment (rarely used) [float]
+    preset:          preset used [str]
+    surround_info:   surround information [str]
+    music_length:    length in bytes of original mp3 [int]
+    music_crc:       CRC-16 of the mp3 music data [int]
+    infotag_crc:     CRC-16 of the info tag [int]
+
+    Prior to ~3.90, Lame simply stored the encoder version in the first frame.
+    If the infotag_crc is invalid, then we try to read this version string.  A
+    simple way to tell if the LAME Tag is complete is to check for the
+    infotag_crc key.
+
+    Replay Gain data is only available since Lame version 3.94b.  If set, the
+    replaygain dict has the following structure:
+
+    \code
+       peak_amplitude: peak signal amplitude [float]
+       radio:
+          name:       name of the gain adjustment [str]
+          adjustment: gain adjustment [float]
+          originator: originator of the gain adjustment [str]
+       audiofile: [same as radio]
+    \endcode
+
+    Note that as of 3.95.1, Lame uses 89dB as a reference level instead of the
+    83dB that is specified in the Replay Gain spec.  This is not automatically
+    compensated for.  You can do something like this if you want:
+
+    \code
+       import eyeD3
+       af = eyeD3.mp3.Mp3AudioFile('/path/to/some.mp3')
+       lamever = af.lameTag['encoder_version']
+       name, ver = lamever[:4], lamever[4:]
+       gain = af.lameTag['replaygain']['radio']['adjustment']
+       if name == 'LAME' and eyeD3.mp3.lamevercmp(ver, '3.95') > 0:
+           gain -= 6
+    \endcode
+
+    Radio and Audiofile Replay Gain are often referrered to as Track and Album
+    gain, respectively.  See http://replaygain.hydrogenaudio.org/ for futher
+    details on Replay Gain.
+
+    See http://gabriel.mp3-tech.org/mp3infotag.html for the gory details of the
+    LAME Tag.
+    """
 
     # from the LAME source:
     # http://lame.cvs.sourceforge.net/*checkout*/lame/lame/libmp3lame/VbrTag.c
@@ -566,11 +554,12 @@ class LameHeader(dict):
         """Read the LAME info tag.
         frame should be the first frame of an mp3.
         """
+        super().__init__()
         self.decode(frame)
 
     def _crc16(self, data, val=0):
         """Compute a CRC-16 checksum on a data stream."""
-        for c in compat.byteiter(data):
+        for c in [bytes([b]) for b in data]:
             val = self._crc16_table[ord(c) ^ (val & 0xff)] ^ (val >> 8)
         return val
 
@@ -590,8 +579,7 @@ class LameHeader(dict):
 
         try:
             # Encoder short VersionString, 9 bytes
-            self['encoder_version'] = \
-                compat.unicode(frame[pos:pos + 9].rstrip(), "latin1")
+            self['encoder_version'] = str(frame[pos:pos + 9].rstrip(), "latin1")
             log.debug('Lame Encoder Version: %s' % self['encoder_version'])
             pos += 9
 
@@ -631,13 +619,13 @@ class LameHeader(dict):
                 adj = bin2dec(bytes2bin(frame[pos:pos + 2])[7:]) / 10.0
                 if sign:
                     adj *= -1
-                # FIXME Lame 3.95.1 and above use 89dB as a reference instead of
-                # 83dB as defined by the Replay Gain spec. Should this be
-                # compensated for?
-                # lamever =self['encoder_version']
-                # if (lamever[:4] == 'LAME' and
-                #       lamevercmp(lamever[4:], '3.95') > 0):
-                #     adj -= 6
+
+                # Lame 3.95.1 and above use 89dB as a reference instead of 83dB as defined by the
+                # Replay Gain spec. This will be compensated for with `adj -= 6`
+                lamever = self['encoder_version']
+                if lamever[:4] == 'LAME' and lamevercmp(lamever[4:], "3.95") > 0:
+                    adj -= 6
+
                 if orig:
                     name = self.REPLAYGAIN_NAME.get(name, 'Unknown')
                     orig = self.REPLAYGAIN_ORIGINATOR.get(orig, 'Unknown')
@@ -772,21 +760,27 @@ class LameHeader(dict):
         return encoder_flags, nogap
 
 
-##
-# \brief Compare LAME version strings.
-#
-# alpha and beta versions are considered older.
-# Versions with sub minor parts or end with 'r' are considered newer.
-#
-# \param x The first version to compare.
-# \param y The second version to compare.
-# \returns Return negative if x<y, zero if x==y, positive if x>y.
 def lamevercmp(x, y):
+    """Compare LAME version strings.
+
+    alpha and beta versions are considered older.
+    Versions with sub minor parts or end with 'r' are considered newer.
+
+    :param x: The first version to compare.
+    :param y: The second version to compare.
+    :returns: Return negative if x<y, zero if x==y, positive if x>y.
+    """
+
+    def cmp(a, b):
+        # This is Python2's built-in `cmp`, which was removed from Python3
+        # And depends on bool - bool yielding the integer -1, 0, 1
+        return (a > b) - (a < b)
+
     x = x.ljust(5)
     y = y.ljust(5)
     if x[:5] == y[:5]:
         return 0
-    ret = compat.cmp(x[:4], y[:4])
+    ret = cmp(x[:4], y[:4])
     if ret:
         return ret
     xmaj, xmin = x.split('.')[:2]
@@ -803,7 +797,7 @@ def lamevercmp(x, y):
         return 1
     if y[4] == ' ':
         return -1
-    return compat.cmp(x[4], y[4])
+    return cmp(x[4], y[4])
 
 
 #                     MPEG1  MPEG2  MPEG2.5
