@@ -1,22 +1,3 @@
-# -*- coding: utf-8 -*-
-################################################################################
-#  Copyright (C) 2002-2015  Travis Shirk <travis@pobox.com>
-#
-#  This program is free software; you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation; either version 2 of the License, or
-#  (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, see <http://www.gnu.org/licenses/>.
-#
-################################################################################
-from __future__ import print_function
 import os
 import re
 import math
@@ -24,12 +5,13 @@ import pathlib
 import logging
 import argparse
 import warnings
-import magic
 import functools
 
-from ..compat import unicode, PY2
+import deprecation
+
 from ..utils.log import getLogger
-from .. import LOCAL_ENCODING, LOCAL_FS_ENCODING
+from .. import LOCAL_FS_ENCODING
+from ..__about__ import __version__
 
 if hasattr(os, "fwalk"):
     os_walk = functools.partial(os.fwalk, follow_symlinks=True)
@@ -44,57 +26,31 @@ else:
         return w
 
 log = getLogger(__name__)
-ID3_MIME_TYPE = "application/x-id3"
-ID3_MIME_TYPE_EXTENSIONS = (".id3", ".tag")
 
 
-class MagicTypes(magic.Magic):
-    def __init__(self):
-        magic.Magic.__init__(self, mime=True, mime_encoding=False, keep_going=True)
+@deprecation.deprecated(deprecated_in="0.9a2", removed_in="1.0", current_version=__version__,
+                        details="Use eyed3.mimetype.guessMimetype() instead.")
+def guessMimetype(filename, with_encoding=False):
+    from .. import mimetype
 
-    def guess_type(self, filename, all_types=False):
-        if os.path.splitext(filename)[1] in ID3_MIME_TYPE_EXTENSIONS:
-            return ID3_MIME_TYPE if not all_types else [ID3_MIME_TYPE]
-        try:
-            types = self.from_file(filename)
-        except UnicodeEncodeError:
-            # https://github.com/ahupp/python-magic/pull/144
-            types = self.from_file(filename.encode("utf-8", 'surrogateescape'))
+    retval = mimetype.guessMimetype(filename)
 
-        delim = r"\012- "
-        if all_types:
-            return types.split(delim)
-        else:
-            return types.split(delim)[0]
-
-
-_mime_types = MagicTypes()
-
-
-def guessMimetype(filename, with_encoding=False, all_types=False):
-    """Return the mime-type for ``filename`` (or list of possible types when `all_types` is True).
-
-    If ``with_encoding`` is True the encoding is included and a 2-tuple is returned, (mine, enc).
-    """
-
-    filename = str(filename) if isinstance(filename, pathlib.Path) else filename
-    mime = _mime_types.guess_type(filename, all_types=all_types)
     if not with_encoding:
-        return mime
+        return retval
     else:
         warnings.warn("File character encoding no longer returned, value is None",
                       UserWarning, stacklevel=2)
-        return mime, None
+        return retval, None
 
 
-def walk(handler, path, excludes=None, fs_encoding=LOCAL_FS_ENCODING):
+def walk(handler, path, excludes=None, fs_encoding=LOCAL_FS_ENCODING, recursive=False):
     """A wrapper around os.walk which handles exclusion patterns and multiple
-    path types (unicode, pathlib.Path, bytes).
+    path types (str, pathlib.Path, bytes).
     """
     if isinstance(path, pathlib.Path):
         path = str(path)
     else:
-        path = unicode(path, fs_encoding) if type(path) is not unicode else path
+        path = str(path, fs_encoding) if type(path) is not str else path
 
     excludes = excludes if excludes else []
     excludes_re = []
@@ -116,11 +72,11 @@ def walk(handler, path, excludes=None, fs_encoding=LOCAL_FS_ENCODING):
         return
 
     for root, dirs, files in [os_walk_unpack(w) for w in os_walk(path)]:
-        root = root if type(root) is unicode else unicode(root, fs_encoding)
+        root = root if type(root) is str else str(root, fs_encoding)
         dirs.sort()
         files.sort()
         for f in files:
-            f = f if type(f) is unicode else unicode(f, fs_encoding)
+            f = f if type(f) is str else str(f, fs_encoding)
             f = os.path.abspath(os.path.join(root, f))
             if not _isExcluded(f):
                 try:
@@ -131,6 +87,9 @@ def walk(handler, path, excludes=None, fs_encoding=LOCAL_FS_ENCODING):
         if files:
             handler.handleDirectory(root, files)
 
+        if not recursive:
+            break
+
 
 class FileHandler(object):
     """A handler interface for :func:`eyed3.utils.walk` callbacks."""
@@ -182,59 +141,22 @@ def _requireArgType(arg_type, *args):
 
 
 def requireUnicode(*args):
-    """Function decorator to enforce unicode argument types.
+    """Function decorator to enforce str/unicode argument types.
     ``None`` is a valid argument value, in all cases, regardless of not being
     unicode.  ``*args`` Positional arguments may be numeric argument index
     values (requireUnicode(1, 3) - requires argument 1 and 3 are unicode)
     or keyword argument names (requireUnicode("title")) or a combination
     thereof.
     """
-    return _requireArgType(unicode, *args)
+    return _requireArgType(str, *args)
 
 
 def requireBytes(*args):
-    """Function decorator to enforce unicode argument types.
-    ``None`` is a valid argument value, in all cases, regardless of not being
-    unicode.  ``*args`` Positional arguments may be numeric argument index
-    values (requireUnicode(1, 3) - requires argument 1 and 3 are unicode)
-    or keyword argument names (requireUnicode("title")) or a combination
-    thereof.
+    """Function decorator to enforce byte string argument types.
     """
     return _requireArgType(bytes, *args)
 
 
-def encodeUnicode(replace=True):
-    warnings.warn("use compat PY2 and be more python3", DeprecationWarning,
-                  stacklevel=2)
-    enc_err = "replace" if replace else "strict"
-
-    if PY2:
-        def wrapper(fn):
-            def wrapped_fn(*args, **kwargs):
-                new_args = []
-                for a in args:
-                    if type(a) is unicode:
-                        new_args.append(a.encode(LOCAL_ENCODING, enc_err))
-                    else:
-                        new_args.append(a)
-                args = tuple(new_args)
-
-                for kw in kwargs:
-                    if type(kwargs[kw]) is unicode:
-                        kwargs[kw] = kwargs[kw].encode(LOCAL_ENCODING, enc_err)
-                return fn(*args, **kwargs)
-            return wrapped_fn
-        return wrapper
-    else:
-        # This decorator is used to encode unicode to bytes for sys.std*
-        # write calls. In python3 unicode (or str) is required by these
-        # functions, the encodig happens internally.. So return a noop
-        def noop(fn):
-            def call(*args, **kwargs):
-                return fn(*args, **kwargs)
-        return noop
-
-
 def formatTime(seconds, total=None, short=False):
     """
     Format ``seconds`` (number of seconds) as a string representation.
@@ -275,40 +197,40 @@ def formatTime(seconds, total=None, short=False):
         return retval
     else:
         units = [
-            (u'y', 60 * 60 * 24 * 7 * 52),
-            (u'w', 60 * 60 * 24 * 7),
-            (u'd', 60 * 60 * 24),
-            (u'h', 60 * 60),
-            (u'm', 60),
-            (u's', 1),
+            ('y', 60 * 60 * 24 * 7 * 52),
+            ('w', 60 * 60 * 24 * 7),
+            ('d', 60 * 60 * 24),
+            ('h', 60 * 60),
+            ('m', 60),
+            ('s', 1),
         ]
 
         seconds = int(seconds)
 
         if seconds < 60:
-            return u'   {0:02d}s'.format(seconds)
+            return '   {0:02d}s'.format(seconds)
         for i in range(len(units) - 1):
             unit1, limit1 = units[i]
             unit2, limit2 = units[i + 1]
             if seconds >= limit1:
-                return u'{0:02d}{1}{2:02d}{3}'.format(
+                return '{0:02d}{1}{2:02d}{3}'.format(
                     seconds // limit1, unit1,
                     (seconds % limit1) // limit2, unit2)
-        return u'  ~inf'
+        return '  ~inf'
 
 
+# Number of bytes per KB (2^10)
 KB_BYTES = 1024
-"""Number of bytes per KB (2^10)"""
+# Number of bytes per MB (2^20)
 MB_BYTES = 1048576
-"""Number of bytes per MB (2^20)"""
+# Number of bytes per GB (2^30)
 GB_BYTES = 1073741824
-"""Number of bytes per GB (2^30)"""
+# Kilobytes abbreviation
 KB_UNIT = "KB"
-"""Kilobytes abbreviation"""
+# Megabytes abbreviation
 MB_UNIT = "MB"
-"""Megabytes abbreviation"""
+# Gigabytes abbreviation
 GB_UNIT = "GB"
-"""Gigabytes abbreviation"""
 
 
 def formatSize(size, short=False):
@@ -336,7 +258,7 @@ def formatSize(size, short=False):
             unit = KB_UNIT
         return "%.2f %s" % (size, unit)
     else:
-        suffixes = u' kMGTPEH'
+        suffixes = ' kMGTPEH'
         if size == 0:
             num_scale = 0
         else:
@@ -436,12 +358,10 @@ class LoggingAction(argparse._AppendAction):
         try:
             logger.setLevel(logging._nameToLevel[level.upper()])
         except KeyError:
-            msg = "invalid level choice: %s (choose from %s)" % \
-                   (level, parser.log_levels)
+            msg = f"invalid level choice: {level} (choose from {parser.log_levels})"
             raise argparse.ArgumentError(self, msg)
 
-        super(LoggingAction, self).__call__(parser, namespace, values,
-                                            option_string)
+        super(LoggingAction, self).__call__(parser, namespace, values, option_string)
 
 
 def datePicker(thing, prefer_recording_date=False):
@@ -468,7 +388,7 @@ def datePicker(thing, prefer_recording_date=False):
                 thing.release_date)
 
 
-def makeUniqueFileName(file_path, uniq=u''):
+def makeUniqueFileName(file_path, uniq=''):
     """The ``file_path`` is the desired file name, and it is returned if the
     file does not exist. In the case that it already exists the path is
     adjusted to be unique. First, the ``uniq`` string is added, and then
@@ -482,8 +402,23 @@ def makeUniqueFileName(file_path, uniq=u''):
         if uniq:
             name = "%s_%s" % (name, uniq)
             file = "".join([name, ext])
-            uniq = u''
+            uniq = ''
         else:
             file = "".join(["%s_%s" % (name, count), ext])
             count += 1
     return os.path.join(path, file)
+
+
+def b(x, encoder=None):
+    """Converts `x` to a bytes string if not already.
+    :param x: The string.
+    :param encoder: Optional codec encoder to perform the conversion. The default is
+                    `codecs.latin_1_encode`.
+    :return: The byte string if conversion was needed.
+    """
+    if isinstance(x, bytes):
+        return x
+    else:
+        import codecs
+        encoder = encoder or codecs.latin_1_encode
+        return encoder(x)[0]
