@@ -1,15 +1,8 @@
-# -*- coding: utf-8 -*-
-from __future__ import print_function
-
 import os
 import struct
 import sys
 import time
 
-from . import formatSize, formatTime
-from .. import LOCAL_ENCODING, compat
-from .log import log
-
 try:
     import fcntl
     import termios
@@ -18,6 +11,8 @@ try:
 except ImportError:
     _CAN_RESIZE_TERMINAL = False
 
+from . import formatSize, formatTime
+
 
 class AnsiCodes(object):
     _USE_ANSI = False
@@ -47,7 +42,7 @@ class AnsiCodes(object):
             if not AnsiCodes._USE_ANSI:
                 return text
 
-            s = u''
+            s = ''
             for st in styles:
                 s += st
             s += color + text + reset
@@ -151,8 +146,8 @@ class Spinner(object):
             for item in enumerate(items):
                 s.next()
     """
-    _default_unicode_chars = u"◓◑◒◐"
-    _default_ascii_chars = u"-/|\\"
+    _default_unicode_chars = "◓◑◒◐"
+    _default_ascii_chars = "-/|\\"
 
     def __init__(self, msg, file=None, step=1,
                  chars=None, use_unicode=True, print_done=True):
@@ -177,9 +172,9 @@ class Spinner(object):
         flush = self._file.flush
 
         while True:
-            write(u'\r')
+            write("\r")
             write(self._msg)
-            write(u' ')
+            write(" ")
             write(chars[index])
             flush()
             yield
@@ -202,13 +197,13 @@ class Spinner(object):
         flush = self._file.flush
 
         if not self._silent:
-            write(u'\r')
+            write("\r")
             write(self._msg)
         if self._print_done:
             if exc_type is None:
-                write(Fore.GREEN + u' [Done]\n')
+                write(Fore.GREEN + ' [Done]\n')
             else:
-                write(Fore.RED + u' [Failed]\n')
+                write(Fore.RED + ' [Failed]\n')
         else:
             write("\n")
         flush()
@@ -329,12 +324,12 @@ class ProgressBar(object):
         self._bar_length = self._terminal_width - 37
 
         bar_fill = int(float(self._bar_length) * frac)
-        write(u'\r|')
-        write(Fore.BLUE + u'=' * bar_fill + Fore.RESET)
+        write("\r|")
+        write(Fore.BLUE + '=' * bar_fill + Fore.RESET)
         if bar_fill < self._bar_length:
-            write(Fore.GREEN + u'>' + Fore.RESET)
-            write(u'-' * (self._bar_length - bar_fill - 1))
-        write(u'|')
+            write(Fore.GREEN + '>' + Fore.RESET)
+            write("-" * (self._bar_length - bar_fill - 1))
+        write("|")
         write(suffix)
 
         self._file.flush()
@@ -349,13 +344,13 @@ class ProgressBar(object):
             time_str = ''
         else:
             t = ((time.time() - self._start_time) * (1.0 - frac)) / frac
-            time_str = u' ETA '
+            time_str = ' ETA '
         if t is not None:
             time_str += formatTime(t, short=True)
 
         suffix = ' {0:>4s}/{1:>4s}'.format(formatSize(value, short=True),
                                            formatSize(self._total, short=True))
-        suffix += u' ({0:>6s}%)'.format(u'{0:.2f}'.format(frac * 100.0))
+        suffix += ' ({0:>6s}%)'.format("{0:.2f}".format(frac * 100.0))
         suffix += time_str
 
         return suffix
@@ -419,36 +414,13 @@ class ProgressBar(object):
         return results
 
 
-def _encode(s):
-    '''This is a helper for output of unicode. With Python2 it is necessary to
-    do encoding to the LOCAL_ENCODING since by default unicode will be encoded
-    to ascii. In python3 this conversion is not necessary for the user to
-    to perform; in fact sys.std*.write, for example, requires unicode strings
-    be passed in. This function will encode for python2 and do nothing
-    for python3 (except assert that ``s`` is a unicode type).'''
-    if compat.PY2:
-        if isinstance(s, compat.unicode):
-            try:
-                return s.encode(LOCAL_ENCODING)
-            except Exception as ex:
-                log.error("Encoding error: " + str(ex))
-                return s.encode(LOCAL_ENCODING, "replace")
-        elif isinstance(s, str):
-            return s
-        else:
-            raise TypeError("Argument must be str or unicode")
-    else:
-        assert(isinstance(s, str))
-        return s
-
-
 def printMsg(s):
     fp = sys.stdout
-    s = _encode(s)
+    assert isinstance(s, str)
     try:
         fp.write("%s\n" % s)
     except UnicodeEncodeError:
-        fp.write("%s\n" % compat.unicode(s.encode("utf-8", "replace"), "utf-8"))
+        fp.write("%s\n" % str(s.encode("utf-8", "replace"), "utf-8"))
     fp.flush()
 
 
@@ -477,21 +449,21 @@ def formatText(s, b=False, c=None):
 
 
 def _printWithColor(s, color, file):
-    s = _encode(s)
+    assert isinstance(s, str)
     file.write(color + s + Fore.RESET + '\n')
     file.flush()
 
 
 def cformat(msg, fg, bg=None, styles=None):
-    '''Format ``msg`` with foreground and optional background. Optional
-    ``styles`` lists will also be applied. The formatted string is returned.'''
+    """Format ``msg`` with foreground and optional background. Optional
+    ``styles`` lists will also be applied. The formatted string is returned."""
     fg = fg or ""
     bg = bg or ""
     styles = "".join(styles or [])
     reset = Fore.RESET + Back.RESET + Style.RESET_ALL if (fg or bg or styles) \
                                                       else ""
 
-    output = u"%(fg)s%(bg)s%(styles)s%(msg)s%(reset)s" % locals()
+    output = "%(fg)s%(bg)s%(styles)s%(msg)s%(reset)s" % locals()
     return output
 
 
@@ -513,7 +485,7 @@ def getTtySize(fd=sys.stdout, check_tty=True):
 
 
 def cprint(msg, fg, bg=None, styles=None, file=sys.stdout):
-    '''Calls ``cformat`` and prints the result to output stream ``file``.'''
+    """Calls ``cformat`` and prints the result to output stream ``file``."""
     print(cformat(msg, fg, bg=bg, styles=styles), file=file)
 
 
@@ -543,20 +515,20 @@ if __name__ == "__main__":
 
     sys.stdout.write("\n")
 
-    with Spinner(Fore.GREEN + u"Phase #1") as spinner:
+    with Spinner(Fore.GREEN + "Phase #1") as spinner:
         for i in range(50):
             time.sleep(.05)
             spinner.next()
-    with Spinner(Fore.RED + u"Phase #2" + Fore.RESET,
+    with Spinner(Fore.RED + "Phase #2" + Fore.RESET,
                  print_done=False) as spinner:
         for i in range(50):
             time.sleep(.05)
             spinner.next()
-    with Spinner(u"Phase #3", print_done=False, use_unicode=False) as spinner:
+    with Spinner("Phase #3", print_done=False, use_unicode=False) as spinner:
         for i in range(50):
             spinner.next()
             time.sleep(.05)
-    with Spinner(u"Phase #4", print_done=False, chars='.oO°Oo.') as spinner:
+    with Spinner("Phase #4", print_done=False, chars='.oO°Oo.') as spinner:
         for i in range(50):
             spinner.next()
             time.sleep(.05)
